abacusai.organization_secret — AbacusAI documentation

# abacusai.organization_secret

## Classes

`OrganizationSecret` | Organization secret

## Module Contents

class abacusai.organization_secret.OrganizationSecret(client, secretKey=None, value=None, createdAt=None, metadata=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Organization secret

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - secretKey (str) – The key of the secret

    - value (str) – The value of the secret

    - createdAt (str) – The date and time when the secret was created, in ISO-8601 format.

    - metadata (dict) – Additional metadata for the secret (e.g., web_app_project_ids).

  secret_key = None
  value = None
  created_at = None
  metadata = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict